@@ -152,23 +152,17 @@ static void remove_badge_from_list(MaukuWidget* mauku_widget, Badge* badge) {
 	badge->previous = badge->next = NULL;
 }
 
-GdkPixbuf* image_cache_get_image(MaukuWidget* mauku_widget, const char* uid) {
+GdkPixbuf* image_cache_get_image(MaukuWidget* mauku_widget, const char* url) {
 	
-	return g_hash_table_lookup(mauku_widget->priv->image_cache, uid);
+	return g_hash_table_lookup(mauku_widget->priv->image_cache, url);
 }
 
-void image_cache_set_image(MaukuWidget* mauku_widget, const char* uid, const void* data, size_t data_size) {
-	GdkPixbufLoader* loader;
+void image_cache_set_image(MaukuWidget* mauku_widget, const char* url, const char* path) {
 	GdkPixbuf* pixbuf;
 	
-	loader = gdk_pixbuf_loader_new();
-	if (gdk_pixbuf_loader_write(loader, data, data_size, NULL) &&
-	    gdk_pixbuf_loader_close(loader, NULL) &&
-	    (pixbuf = gdk_pixbuf_loader_get_pixbuf(loader))) {
-		g_object_ref(pixbuf);
-		g_hash_table_insert(mauku_widget->priv->image_cache, g_strdup(uid), pixbuf);
+	if ((pixbuf = gdk_pixbuf_new_from_file(path, NULL))) {
+		g_hash_table_insert(mauku_widget->priv->image_cache, g_strdup(url), pixbuf);
 	}
-	g_object_unref(loader);
 }
 
 static gboolean view_hide_show_timeout(void* user_data) {
@@ -326,7 +320,7 @@ static void item_added(MicrofeedSubscriber* subscriber, const char* publisher, c
 		}
 		if ((sender_image = microfeed_item_get_property(item, "user.image")) &&
 		    !image_cache_get_image(mauku_widget, sender_image)) {
-			microfeed_subscriber_send_item_data(subscriber, publisher, MICROFEED_FEED_URI_IMAGES, sender_image, NULL, NULL);
+			microfeed_subscriber_store_data(subscriber, publisher, sender_image, NULL, NULL);
 		}
 		if (!(sender_nick = microfeed_item_get_property(item, "user.nick"))) {
 			sender_nick = "<unknown>";
@@ -368,16 +362,16 @@ static void item_status_changed(MicrofeedSubscriber* subscriber, const char* pub
 	printf("Status changed: %s %s %s %u\n", publisher, uri, uid, (unsigned int)status);
 }
 
-static void item_data(MicrofeedSubscriber* subscriber, const char* publisher, const char* uri, const char* uid, const void* data, const size_t length, void* user_data) {
+static void data_stored(MicrofeedSubscriber* subscriber, const char* publisher, const char* url, const char* path, void* user_data) {
 	MaukuWidget* mauku_widget;
 	int width;
 	int height;
 	
 	mauku_widget = MAUKU_WIDGET(user_data);
 	
-	printf("Data: %s %s %s (length: %u)\n", publisher, uri, uid, length);
-	image_cache_set_image(mauku_widget, uid, data, length);
-	if (!mauku_widget->priv->current_badge->sender_image || !strcmp(mauku_widget->priv->current_badge->sender_image, uid)) {
+	printf("Data: %s %s %s\n", publisher, url, path);
+	image_cache_set_image(mauku_widget, url, path);
+	if (!mauku_widget->priv->current_badge->sender_image || !strcmp(mauku_widget->priv->current_badge->sender_image, url)) {
 		if (mauku_widget->priv->cairo_surface) {
 			cairo_surface_destroy(mauku_widget->priv->cairo_surface);
 			mauku_widget->priv->cairo_surface = NULL;
@@ -401,7 +395,6 @@ static MicrofeedSubscriberCallbacks images_callbacks = {
 	NULL,
 	NULL,
 	NULL,
-	item_data
 };
 
 static MicrofeedSubscriberCallbacks overview_callbacks = {
@@ -415,7 +408,6 @@ static MicrofeedSubscriberCallbacks overview_callbacks = {
 	item_added, /* item_republished */
 	item_removed,
 	item_status_changed,
-	NULL
 };
 
 static gboolean on_configure_event(GtkWidget* widget, GdkEventConfigure* event, gpointer user_data) {
@@ -666,8 +658,8 @@ static gboolean on_button_release_event(GtkWidget* widget, GdkEventButton* event
 }
 
 static void configured_subscribe(MicrofeedSubscriber* subscriber, const char* publisher, void* user_data) {
-	microfeed_subscriber_subscribe_feed(subscriber, publisher, MICROFEED_FEED_URI_IMAGES, &images_callbacks, user_data, NULL, NULL);
 	microfeed_subscriber_subscribe_feed(subscriber, publisher, MICROFEED_FEED_URI_OVERVIEW, &overview_callbacks, user_data, feed_subscribed, user_data);
+	microfeed_subscriber_add_data_stored_callback(subscriber, publisher, data_stored, user_data);
 }
 
 static void configured_unsubscribe(MicrofeedSubscriber* subscriber, const char* publisher, const char* uri, MicrofeedSubscriberCallbacks* callbacks, void* callbacks_user_data, void* user_data) {
